@@ -13,20 +13,18 @@
 ##############################################################################
 
 """
-$Id: app.py 117126 2010-10-01 15:32:33Z adamg $
+$Id: app.py 114887 2010-07-21 12:06:15Z adamg $
 """
 __docformat__ = 'restructuredtext'
 
 import persistent
 import zope.interface
 
+from zope.container import contained
 from zope.schema.fieldproperty import FieldProperty
-from zope.i18n.interfaces import IUserPreferredLanguages
 from zope.i18n.interfaces import INegotiator
 from zope.i18n.negotiator import negotiator
 
-from zope.app.container import contained
-
 from z3c.language.session.interfaces import ILanguageSession
 
 from z3c.language.negotiator.interfaces import INegotiatorManager
@@ -36,16 +34,16 @@ from z3c.language.negotiator.interfaces import LANGUAGE_CACHE_KEY
 
 
 class Negotiator(persistent.Persistent, contained.Contained):
-    """Local negotiator implementation.
+    """Loacal negotiator implementation.
 
     The negotiator let you change the policy, which is a alias
     for the lookup mechanism.
 
     'server' -- The server defines the language
 
-    'session' -- The session defines the language (useful for testing)
+    'session' -- The session defines the language (usefull for testing)
 
-    'browser' -- The browser defines the language (useful for testing)
+    'browser' -- The browser defines the language (usefull for testing)
 
     'browser --> session --> server' -- Left criteria first
 
@@ -82,7 +80,7 @@ class Negotiator(persistent.Persistent, contained.Contained):
             self._policy = policy
         return property(get, set)
 
-    def getLanguage(self, languages, request):
+    def _getLanguage(self, languages, request):
         """Returns the language dependent on the policy."""
         policyList = self._policy.split(' --> ')
 
@@ -95,21 +93,10 @@ class Negotiator(persistent.Persistent, contained.Contained):
 
             # the language is handled by a session
             elif policy == 'session':
-                if self.cacheEnabled:
-                    try:
-                        cached = request.annotations[LANGUAGE_CACHE_KEY]
-                        return cached
-                    except KeyError:
-                        session = ILanguageSession(request)
-                        lang = session.getLanguage()
-                        if lang is not None:
-                            request.annotations[LANGUAGE_CACHE_KEY] = lang
-                            return lang
-                else:
-                    session = ILanguageSession(request)
-                    lang = session.getLanguage()
-                    if lang is not None:
-                        return lang
+                session = ILanguageSession(request)
+                lang = session.getLanguage()
+                if lang is not None:
+                    return lang
 
             # the language is handled by the browsers language settings
             elif policy == 'browser':
@@ -119,6 +106,17 @@ class Negotiator(persistent.Persistent, contained.Contained):
 
         return None
 
+    def getLanguage(self, languages, request):
+        if self.cacheEnabled:
+            try:
+                return request.annotations[LANGUAGE_CACHE_KEY]
+            except KeyError:
+                lang = self._getLanguage(languages, request)
+                request.annotations[LANGUAGE_CACHE_KEY] = lang
+                return lang
+        else:
+            return self._getLanguage(languages, request)
+
     def clearCache(self, request):
         try:
             del request.annotations[LANGUAGE_CACHE_KEY]
