@@ -13,7 +13,7 @@
 ##############################################################################
 
 """
-$Id: tests.py 117126 2010-10-01 15:32:33Z adamg $
+$Id: tests.py 114887 2010-07-21 12:06:15Z adamg $
 """
 __docformat__ = 'restructuredtext'
 
@@ -125,7 +125,7 @@ class NegotiatorTest(zope.component.testing.PlacelessSetup,
 
         self.negotiator.serverLanguage = u'en'
 
-        self.assertEqual(self.negotiator.getLanguage(('en', 'de'), env), 'en')
+        self.assertEqual(self.negotiator.getLanguage(('en', 'de'), env), 'de')
 
         env = testing.EnvStub(('pt-br','en'))
 
@@ -133,7 +133,7 @@ class NegotiatorTest(zope.component.testing.PlacelessSetup,
 
         self.negotiator.serverLanguage = u'de'
 
-        self.assertEqual(self.negotiator.getLanguage(('en', 'de'), env), 'de')
+        self.assertEqual(self.negotiator.getLanguage(('en', 'de'), env), 'en')
 
         self.negotiator.clearCache(env)
 
@@ -142,24 +142,12 @@ class NegotiatorTest(zope.component.testing.PlacelessSetup,
         self.negotiator.clearCache(env)
         self.negotiator.clearCache(env)
 
-        #edge case, cache has a more specific language than available
-        self.negotiator.policy = 'browser'
-        env = testing.EnvStub(('de-de','de'))
-
-        self.assertEqual(self.negotiator.getLanguage(('de-de', 'de'), env), 'de-de')
-
-        self.assertEqual(self.negotiator.getLanguage(('de', 'en'), env), 'de')
-
-        self.negotiator.clearCache(env)
-
 
 def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(NegotiatorBaseTest),
         unittest.makeSuite(NegotiatorTest),
         DocFileSuite('README.txt',
-            setUp=testing.doctestSetUp,
-            tearDown=testing.doctestTearDown,
             optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS),
         ))
 
